This is an automated email from the ASF dual-hosted git repository.

wangzx pushed a commit to branch gh-pages
in repository https://gitbox.apache.org/repos/asf/echarts-examples.git


The following commit(s) were added to refs/heads/gh-pages by this push:
     new 94c476dd tweak editor name
94c476dd is described below

commit 94c476dd66bb425a0c2d195137e4c5ffbb5615a3
Author: plainheart <y...@all-my-life.cn>
AuthorDate: Tue May 3 16:33:39 2022 +0800

    tweak editor name
---
 src/common/i18n.js                         | 4 ++--
 src/editor/Editor.vue                      | 8 ++++----
 src/editor/sandbox/openwith/codesandbox.js | 4 ++--
 3 files changed, 8 insertions(+), 8 deletions(-)

diff --git a/src/common/i18n.js b/src/common/i18n.js
index 06f9cc4a..018f24ed 100644
--- a/src/common/i18n.js
+++ b/src/common/i18n.js
@@ -3,7 +3,7 @@ export default {
     editor: {
       run: 'Run',
       format: 'Format',
-      openWithCodeSandBox: 'Open with CodeSandBox',
+      openWithCodeSandbox: 'Open with CodeSandbox',
       openWithCodePen: 'Open with CodePen',
       errorInEditor: 'Errors exist in code!',
       infiniteLoopInEditor: 'Potential infinite loops exist in code!',
@@ -95,7 +95,7 @@ export default {
     editor: {
       run: '运行',
       format: '格式化',
-      openWithCodeSandBox: '在 CodeSandBox 中编辑',
+      openWithCodeSandbox: '在 CodeSandbox 中编辑',
       openWithCodePen: '在 CodePen 中编辑',
       errorInEditor: '编辑器内容有误!',
       infiniteLoopInEditor: '编辑器内容可能存在无限循环!',
diff --git a/src/editor/Editor.vue b/src/editor/Editor.vue
index 49b49497..db8dd865 100644
--- a/src/editor/Editor.vue
+++ b/src/editor/Editor.vue
@@ -56,8 +56,8 @@
                 </a>
                 <a
                   class="btn btn-sm codesandbox"
-                  @click="toExternalEditor('CodeSandBox')"
-                  :title="$t('editor.openWithCodeSandBox')"
+                  @click="toExternalEditor('CodeSandbox')"
+                  :title="$t('editor.openWithCodeSandbox')"
                 >
                   <svg
                     viewBox="0 0 512 512"
@@ -206,7 +206,7 @@ import './object-visualizer.css';
 import { URL_PARAMS } from '../common/config';
 import { formatCode } from '../common/helper';
 import openWithCodePen from './sandbox/openwith/codepen';
-import openWithCodeSandBox from './sandbox/openwith/codesandbox';
+import openWithCodeSandbox from './sandbox/openwith/codesandbox';
 
 export default {
   components: {
@@ -280,7 +280,7 @@ export default {
       const assets = previewRef.getAssets();
       const vendors = {
         CodePen: openWithCodePen,
-        CodeSandBox: openWithCodeSandBox
+        CodeSandbox: openWithCodeSandbox
       };
       vendors[vendor](
         this.exampleConfig && this.exampleConfig.title,
diff --git a/src/editor/sandbox/openwith/codesandbox.js 
b/src/editor/sandbox/openwith/codesandbox.js
index 7e74d77d..5d89c22a 100644
--- a/src/editor/sandbox/openwith/codesandbox.js
+++ b/src/editor/sandbox/openwith/codesandbox.js
@@ -2,12 +2,12 @@ import { getParameters } from 'codesandbox/lib/api/define';
 import { getTemplates } from './helper';
 
 /**
  * Open with CodeSandBox
  * @param {string} code
  * @param {Array<{ src?: string, content?: string }>} scripts
  * @param {string} css
  */
-export default function openWithCodeSandBox(title, scripts, css) {
+export default function openWithCodeSandbox(title, scripts, css) {
   const templates = getTemplates(title, scripts, css);
   title = templates.title.split(' - ');
 


---------------------------------------------------------------------
@@ -2,12 +2,12 @@ import { getParameters } from 'codesandbox/lib/api/define';
 
 /**
- * Open with CodeSandBox
+ * Open with CodeSandbox
  * @param {string} code
  * @param {Array<{ src?: string, content?: string }>} scripts
To unsubscribe, e-mail: commits-unsubscr...@echarts.apache.org
For additional commands, e-mail: commits-h...@echarts.apache.org

Reply via email to